@@ -13,8 +13,8 @@
 
     Last commit info:
     ~~~~~~~~~~~~~~~~~
-    $LastChangedDate: 2010-01-20 16:41:53 +0100 (Mi, 20 Jan 2010) $
-    $Rev: 41 $
+    $LastChangedDate: 2010-04-04 19:49:21 +0200 (So, 04. Apr 2010) $
+    $Rev: 42 $
     $Author: google.groups@jensdiemer.de $
 
     :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
@@ -480,6 +480,7 @@ class CrossCompareTests(BaseCreoleTest):
             greater-than sign: &gt;</p>
         """)
 
+
 #    def test_macro_html1(self):
 #        self.assertCreole(r"""
 #            <<a_not_existing_macro>>
